@@ -25,7 +25,7 @@ class AddressSchema(Schema):
 
     id = fields.Integer()
     user_id = fields.Integer(load_only=True)
-    zip_code = fields.String(attribute='zipCode')
+    zip_code = fields.String(data_key='zipCode')
     city = fields.String()
     address = fields.String()
     description = fields.String(allow_none=True)
